==> mingw-w64-freecad-1.0rc1-1.src.tar.zst: FreeCAD-1.0rc1/src/Mod/Start/Gui/Resources/translations/StartPage_pt-BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt-BR" sourcelanguage="en">
  <context>
    <name>StartGui::FirstStartWidget</name>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="95"/>
      <source>Done</source>
      <translation>Feito</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="97"/>
      <source>Welcome to %1</source>
      <translation>Bem-vindo ao %1</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="100"/>
      <source>To get started, set your basic configuration options below.</source>
      <translation>Para começar, defina suas opções básicas de configuração abaixo.</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="101"/>
      <source>These options (and many more) can be changed later in Preferences.</source>
      <translation>Essas opções (e muito mais) podem ser alteradas posteriormente em Preferências.</translation>
    </message>
  </context>
  <context>
    <name>StartGui::GeneralSettingsWidget</name>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="212"/>
      <source>Language</source>
      <translation>Idioma</translation>
    </message>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="213"/>
      <source>Unit System</source>
      <translation>Sistema de Unidades</translation>
    </message>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="226"/>
      <source>Navigation Style</source>
      <translation>Estilo de navegação</translation>
    </message>
  </context>
  <context>
    <name>CmdStart</name>
    <message>
      <location filename="../../Manipulator.cpp" line="47"/>
      <location filename="../../Manipulator.cpp" line="48"/>
      <source>Start</source>
      <translation>Iniciar</translation>
    </message>
    <message>
      <location filename="../../Manipulator.cpp" line="49"/>
      <source>Displays the Start in an MDI view</source>
      <translation>Exibe a página de início em uma vista MDI</translation>
    </message>
  </context>
  <context>
    <name>StartGui::StartView</name>
    <message>
      <location filename="../../StartView.cpp" line="208"/>
      <source>Empty file</source>
      <translation>Arquivo vazio</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="209"/>
      <source>Create a new empty FreeCAD file</source>
      <translation>Criar um novo arquivo FreeCAD vazio</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="211"/>
      <source>Open File</source>
      <translation>Abrir arquivo</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="212"/>
      <source>Open an existing CAD file or 3D model</source>
      <translation>Abrir um arquivo CAD existente ou modelo 3D</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="214"/>
      <source>Parametric Part</source>
      <translation>Peça paramétrica</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="215"/>
      <source>Create a part with the Part Design workbench</source>
      <translation>Crie uma peça com a bancada de trabalho Part Design</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="217"/>
      <source>Assembly</source>
      <translation>Assemblagem</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="218"/>
      <source>Create an assembly project</source>
      <translation>Criar um projeto de montagem</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="220"/>
      <source>2D Draft</source>
      <translation>Desenho 2D</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="221"/>
      <source>Create a 2D Draft with the Draft workbench</source>
      <translation>Crie um desenho 2D com a bancada de trabalho Draft</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="223"/>
      <source>BIM/Architecture</source>
      <translation>BIM/Arquitetura</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="224"/>
      <source>Create an architectural project</source>
      <translation>Criar um projeto arquitetônico</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="488"/>
      <source>New File</source>
      <translation>Novo arquivo</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="489"/>
      <source>Examples</source>
      <translation>Exemplos</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="490"/>
      <source>Recent Files</source>
      <translation>Arquivos Recentes</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="493"/>
      <source>Open first start setup</source>
      <translation type="unfinished">Open first start setup</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="495"/>
      <source>Don't show this Start page again (start with blank screen)</source>
      <translation>Não mostrar esta página inicial novamente (começar com tela em branco)</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../StartView.cpp" line="482"/>
      <source>Start</source>
      <translation>Começar</translation>
    </message>
  </context>
  <context>
    <name>StartGui::ThemeSelectorWidget</name>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="58"/>
      <source>FreeCAD Classic</source>
      <translation>FreeCAD Clássico</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="59"/>
      <source>FreeCAD Dark</source>
      <translation>FreeCAD Escuro</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="60"/>
      <source>FreeCAD Light</source>
      <translation>FreeCAD Claro</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="166"/>
      <source>Theme</source>
      <translation>Tema</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="167"/>
      <source>Looking for more themes? You can obtain them using &lt;a href="freecad:Std_AddonMgr"&gt;Addon Manager&lt;/a&gt;.</source>
      <translation>Procurando por mais temas? Você pode obtê-los usando o &lt;a href="freecad:Std_AddonMgr"&gt;Addon Manager&lt;/a&gt;.</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="169"/>
      <source>FreeCAD Dark</source>
      <comment>Visual theme name</comment>
      <translation>FreeCAD Escuro</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="170"/>
      <source>FreeCAD Light</source>
      <comment>Visual theme name</comment>
      <translation>FreeCAD Claro</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="171"/>
      <source>FreeCAD Classic</source>
      <comment>Visual theme name</comment>
      <translation>FreeCAD Clássico</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0.0-2.src.tar.zst: FreeCAD-1.0.0/src/Mod/Start/Gui/Resources/translations/StartPage_pt-BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt-BR" sourcelanguage="en">
  <context>
    <name>StartGui::FirstStartWidget</name>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="94"/>
      <source>Done</source>
      <translation>Feito</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="96"/>
      <source>Welcome to %1</source>
      <translation>Bem-vindo ao %1</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="99"/>
      <source>To get started, set your basic configuration options below.</source>
      <translation>Para começar, defina suas opções básicas de configuração abaixo.</translation>
    </message>
    <message>
      <location filename="../../FirstStartWidget.cpp" line="100"/>
      <source>These options (and many more) can be changed later in Preferences.</source>
      <translation>Essas opções (e muito mais) podem ser alteradas posteriormente em Preferências.</translation>
    </message>
  </context>
  <context>
    <name>StartGui::GeneralSettingsWidget</name>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="212"/>
      <source>Language</source>
      <translation>Idioma</translation>
    </message>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="213"/>
      <source>Unit System</source>
      <translation>Sistema de Unidades</translation>
    </message>
    <message>
      <location filename="../../GeneralSettingsWidget.cpp" line="226"/>
      <source>Navigation Style</source>
      <translation>Estilo de navegação</translation>
    </message>
  </context>
  <context>
    <name>CmdStart</name>
    <message>
      <location filename="../../Manipulator.cpp" line="47"/>
      <location filename="../../Manipulator.cpp" line="48"/>
      <source>Start</source>
      <translation>Iniciar</translation>
    </message>
    <message>
      <location filename="../../Manipulator.cpp" line="49"/>
      <source>Displays the Start in an MDI view</source>
      <translation>Exibe a página de início em uma vista MDI</translation>
    </message>
  </context>
  <context>
    <name>StartGui::StartView</name>
    <message>
      <location filename="../../StartView.cpp" line="289"/>
      <source>Empty file</source>
      <translation>Arquivo vazio</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="290"/>
      <source>Create a new empty FreeCAD file</source>
      <translation>Criar um novo arquivo FreeCAD vazio</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="293"/>
      <source>Open File</source>
      <translation>Abrir arquivo</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="294"/>
      <source>Open an existing CAD file or 3D model</source>
      <translation>Abrir um arquivo CAD existente ou modelo 3D</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="297"/>
      <source>Parametric Part</source>
      <translation>Peça paramétrica</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="298"/>
      <source>Create a part with the Part Design workbench</source>
      <translation>Crie uma peça com a bancada de trabalho Part Design</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="301"/>
      <source>Assembly</source>
      <translation>Assemblagem</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="302"/>
      <source>Create an assembly project</source>
      <translation>Criar um projeto de montagem</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="305"/>
      <source>2D Draft</source>
      <translation>Desenho 2D</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="306"/>
      <source>Create a 2D Draft with the Draft workbench</source>
      <translation>Crie um desenho 2D com a bancada de trabalho Draft</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="309"/>
      <source>BIM/Architecture</source>
      <translation>BIM/Arquitetura</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="310"/>
      <source>Create an architectural project</source>
      <translation>Criar um projeto arquitetônico</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="525"/>
      <source>New File</source>
      <translation>Novo arquivo</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="526"/>
      <source>Examples</source>
      <translation>Exemplos</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="527"/>
      <source>Recent Files</source>
      <translation>Arquivos Recentes</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="530"/>
      <source>Open first start setup</source>
      <translation>Abrir a configuração inicial</translation>
    </message>
    <message>
      <location filename="../../StartView.cpp" line="532"/>
      <source>Don't show this Start page again (start with blank screen)</source>
      <translation>Não mostrar esta página inicial novamente (começar com tela em branco)</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../StartView.cpp" line="519"/>
      <source>Start</source>
      <translation>Começar</translation>
    </message>
  </context>
  <context>
    <name>StartGui::ThemeSelectorWidget</name>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="113"/>
      <source>FreeCAD Classic</source>
      <translation>FreeCAD Clássico</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="114"/>
      <source>FreeCAD Dark</source>
      <translation>FreeCAD Escuro</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="115"/>
      <source>FreeCAD Light</source>
      <translation>FreeCAD Claro</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="238"/>
      <source>Theme</source>
      <translation>Tema</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="239"/>
      <source>Looking for more themes? You can obtain them using &lt;a href="freecad:Std_AddonMgr"&gt;Addon Manager&lt;/a&gt;.</source>
      <translation>Procurando por mais temas? Você pode obtê-los usando o &lt;a href="freecad:Std_AddonMgr"&gt;Addon Manager&lt;/a&gt;.</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="241"/>
      <source>FreeCAD Dark</source>
      <comment>Visual theme name</comment>
      <translation>FreeCAD Escuro</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="242"/>
      <source>FreeCAD Light</source>
      <comment>Visual theme name</comment>
      <translation>FreeCAD Claro</translation>
    </message>
    <message>
      <location filename="../../ThemeSelectorWidget.cpp" line="243"/>
      <source>FreeCAD Classic</source>
      <comment>Visual theme name</comment>
      <translation>FreeCAD Clássico</translation>
    </message>
  </context>
</TS>
